@@ -48,7 +48,7 @@ class ClockLogger:
         if '[Stop]' in description and len(self.lines) > 2:
             description = self.lines[-2][6:]
 
-        return description
+        return description.replace('\r', '').replace('\n', '')
 
     # Finds position of entry given the 'at' hour (today)
     def find_position(self, at):
